yt.data\_objects.derived\_quantities module
===========================================

.. automodule:: yt.data_objects.derived_quantities
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
